@@ -1,6 +1,6 @@
 package Venus::Hash;
 
-use 5.014;
+use 5.018;
 
 use strict;
 use warnings;
@@ -221,7 +221,7 @@ sub keys {
 sub list {
   my ($self) = @_;
 
-  return (%{$self->value});
+  return wantarray ? (%{$self->value}) : scalar(CORE::keys(%{$self->value}));
 }
 
 sub map {
